@@ -6,6 +6,11 @@ class Cache:
     CACHE_TIMEOUT = 5 * 60  # 5 * 60 seconds
     TIMEOUT_KEY = 'last_access_time'
 
+    session_details = 'session_details'
+    system_bars = 'system_bars'
+    window_size = 'window_size'
+    viewport = 'viewport'
+
     @classmethod
     def set_cache(cls, session_id, property, value):
         if not isinstance(session_id, str):
