@@ -1,5 +1,6 @@
 import os
 import tempfile
+from pathlib import Path
 
 from appium.webdriver.webdriver import WebDriver
 
@@ -11,6 +12,7 @@ class GenericProvider:
     def __init__(self, driver: WebDriver, metadata):
         self.driver = driver
         self.metadata = metadata
+        self.debug_url = ''
 
     @staticmethod
     def supports(_remote_url):
@@ -65,14 +67,17 @@ class GenericProvider:
         return filepath
 
     def get_debug_url(self):
-        return ''
+        return self.debug_url
 
     def get_device_name(self):
         return ''
 
     def _get_dir(self):
-        dir_path = tempfile.mkdtemp()
-        return dir_path
+        dir_path = os.environ.get('PERCY_TMP_DIR') or None
+        if dir_path:
+            Path(dir_path).mkdir(parents=True, exist_ok=True)
+            return dir_path
+        return tempfile.mkdtemp()
 
     def _get_path(self, directory):
         suffix = '.png'
